@@ -39,10 +39,10 @@ class UserManager : public KCModule
     Q_OBJECT
     public:
         explicit UserManager(QWidget *parent, const QVariantList& args);
-        ~UserManager() Q_DECL_OVERRIDE;
+        ~UserManager() override;
 
-        void load() Q_DECL_OVERRIDE;
-        void save() Q_DECL_OVERRIDE;
+        void load() override;
+        void save() override;
 
     public Q_SLOTS:
         void currentChanged(const QModelIndex &selected, const QModelIndex &previous);
